@@ -5,9 +5,8 @@ from dbt.adapters.spark.column import SparkColumn  # noqa
 from dbt.adapters.spark.impl import SparkAdapter
 
 from dbt.adapters.base import AdapterPlugin
-from dbt.include import spark
+from dbt.include import spark  # type: ignore
 
 Plugin = AdapterPlugin(
-    adapter=SparkAdapter,
-    credentials=SparkCredentials,
-    include_path=spark.PACKAGE_PATH)
+    adapter=SparkAdapter, credentials=SparkCredentials, include_path=spark.PACKAGE_PATH
+)
